@@ -182,7 +182,7 @@ wtap_encaps = {
 	["SITA"] = 100,
 	["SCCP"] = 101,
 	["BLUETOOTH_HCI"] = 102,
-	["IPMB"] = 103,
+	["IPMB_KONTRON"] = 103,
 	["IEEE802_15_4"] = 104,
 	["X2E_XORAYA"] = 105,
 	["FLEXRAY"] = 106,
@@ -191,7 +191,7 @@ wtap_encaps = {
 	["CAN20B"] = 109,
 	["LAYER1_EVENT"] = 110,
 	["X2E_SERIAL"] = 111,
-	["I2C"] = 112,
+	["I2C_LINUX"] = 112,
 	["IEEE802_15_4_NONASK_PHY"] = 113,
 	["TNEF"] = 114,
 	["USB_LINUX_MMAPPED"] = 115,
@@ -285,7 +285,9 @@ wtap_encaps = {
 	["SYSTEMD_JOURNAL"] = 203,
 	["EBHSCR"] = 204,
 	["VPP"] = 205,
-	["IEEE802_15_4_TAP"] = 206
+	["IEEE802_15_4_TAP"] = 206,
+	["LOG_3GPP"] = 207,
+	["USB_2_0"] = 208
 }
 wtap = wtap_encaps -- for bw compatibility
 
@@ -374,6 +376,7 @@ wtap_filetypes = {
 	["RFC7468"] = 82,
 	["RUBY_MARSHAL"] = 83,
 	["SYSTEMD_JOURNAL"] = 84,
+	["LOG_3GPP"] = 85,
 	["TSPREC_SEC"] = 0,
 	["TSPREC_DSEC"] = 1,
 	["TSPREC_CSEC"] = 2,
@@ -514,6 +517,7 @@ base = {
 	["LOCAL"] = 1000,  -- local time in our time zone, with month and day
 	["UTC"] = 1001,  -- UTC, with month and day
 	["DOY_UTC"] = 1002,  -- UTC, with 1-origin day-of-year
+	["NTP_UTC"] = 1003,  -- UTC, with "NULL" when timestamp is all zeros
 }
 
 
@@ -533,8 +537,11 @@ ENC_TIME_MSECS = 20
 ENC_TIME_SECS_NTP = 24
 ENC_TIME_RFC_3971 = 32
 ENC_TIME_MSEC_NTP = 34
-ENC_CHARENCODING_MASK = 2147483646
+ENC_TIME_MIP6 = 36
+ENC_ZIGBEE = 1073741824
+ENC_CHARENCODING_MASK = 1073741822
 ENC_ASCII = 0
+ENC_ISO_646_IRV = 14
 ENC_UTF_8 = 2
 ENC_UTF_16 = 4
 ENC_UCS_2 = 6
@@ -562,10 +569,11 @@ ENC_CP437 = 50
 ENC_ASCII_7BITS = 52
 ENC_T61 = 54
 ENC_EBCDIC_CP037 = 56
-ENC_ZIGBEE = 58
+ENC_WINDOWS_1252 = 58
 ENC_WINDOWS_1251 = 60
 ENC_CP855 = 62
 ENC_CP866 = 64
+ENC_ISO_646_BASIC = 66
 ENC_NA = 0
 ENC_STR_NUM = 16777216
 ENC_STR_HEX = 33554432
@@ -574,6 +582,7 @@ ENC_STR_MASK = 65534
 ENC_NUM_PREF = 2097152
 ENC_VARINT_PROTOBUF = 2
 ENC_VARINT_QUIC = 4
+ENC_VARINT_ZIGZAG = 8
 ENC_SEP_NONE = 65536
 ENC_SEP_COLON = 131072
 ENC_SEP_DASH = 262144
@@ -682,6 +691,12 @@ MENU_STAT_TELEPHONY_SCTP = 12
 MENU_TOOLS_UNSORTED = 13
 
 
+-- the possible values for Pinfo's p2p_dir attribute
+P2P_DIR_UNKNOWN = -1
+P2P_DIR_SENT    =  0
+P2P_DIR_RECV    =  1
+
+
 -- other useful constants
 -- DATA_DIR and USER_DIR have a trailing directory separator.
 GUI_ENABLED = gui_enabled()
